@@ -1,5 +1,4 @@
 from __future__ import print_function, unicode_literals, division, absolute_import
-from django.shortcuts import render
 from django.contrib.auth.decorators import login_required
 from django.http import HttpResponse, HttpResponseForbidden
 from django.views.decorators.csrf import csrf_exempt
@@ -9,10 +8,7 @@ import flat.users
 from flat.views import initdoc, query
 import json
 import sys
-if sys.version < '3':
-    from urllib2 import URLError
-else:
-    from urllib.error import URLError
+from urllib.error import URLError
 
 
 
