@@ -14,8 +14,9 @@ from django.http import HttpResponse, HttpResponseForbidden, HttpResponseRedirec
 import django.contrib.auth
 from django.conf import settings
 
-from pynlpl.formats import fql
+from folia import fql
 
+from flat import VERSION
 import flat.comm
 import flat.users
 from flat.converters import get_converters, inputformatchangefunction
@@ -35,7 +36,12 @@ def getcontext(request,namespace,docid, doc, mode, configuration = None):
             raise Exception("Session has been logged out")
         else:
             configuration = request.session['configuration']
+    if request.user:
+        authenticated = request.user.is_authenticated if isinstance(request.user.is_authenticated, bool) else request.user.is_authenticated()
+    else:
+        authenticated = False
     return {
+            'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "",
             'configuration_id': configuration,
             'configuration': settings.CONFIGURATIONS[configuration],
             'configuration_json': json.dumps(settings.CONFIGURATIONS[configuration]),
@@ -47,14 +53,17 @@ def getcontext(request,namespace,docid, doc, mode, configuration = None):
             'modes_json': json.dumps([x[0] for x in settings.CONFIGURATIONS[configuration]['modes'] ]),
             'perspectives_json': json.dumps(settings.CONFIGURATIONS[configuration]['perspectives']),
             'docdeclarations': json.dumps(doc['declarations']) if 'declarations' in doc else "{}",
+            'provenance': json.dumps(doc['provenance']) if 'provenance' in doc else "{}",
             'setdefinitions': json.dumps(doc['setdefinitions']) if 'setdefinitions' in doc else "{}",
+            'failedsetdefinitions': json.dumps(doc['failedsetdefinitions']) if 'failedsetdefinitions' in doc else "[]",
+            'provenance': json.dumps(doc['provenance']) if 'provenance' in doc else "{}",
             'excludeclasses': json.dumps(settings.CONFIGURATIONS[configuration]['excludeclasses']) if 'excludeclasses' in settings.CONFIGURATIONS[configuration] else "{}",
             'metadata': json.dumps(doc['metadata']) if 'metadata' in doc else "{}",
             'toc': json.dumps(doc['toc']) if 'toc' in doc else "[]",
             'slices': json.dumps(doc['slices']) if 'slices' in doc else "{}",
             'slicesize': json.dumps(doc['slicesize']) if 'slicesize' in doc else "{}",
             'rtl': True if 'rtl' in doc and doc['rtl'] else False,
-            'loggedin': request.user.is_authenticated() if request.user else False,
+            'loggedin': authenticated,
             'isadmin': request.user.is_staff if request.user else False,
             'version': settings.VERSION,
             'username': request.user.username if namespace != "pub" else "anonymous",
@@ -87,7 +96,6 @@ def getbody(html):
 
 def docserveerror(e, d=None):
     if d is None: d={}
-    raise e
     if isinstance(e, HTTPError):
         body = getbody(e.read())
         d['fatalerror'] =  "<strong>Fatal Error:</strong> The document server returned an error<pre style=\"font-weight: bold\">" + str(e) + "</pre><pre>" + body +"</pre>"
@@ -108,6 +116,7 @@ def docserveerror(e, d=None):
     elif isinstance(e, Exception):
         # we don't handle other exceptions, raise!
         raise e
+    d['base_prefix'] = settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""
     return d
 
 
@@ -115,15 +124,16 @@ def initdoc(request, namespace, docid, mode, template, context=None, configurati
     """Initialise a document (not invoked directly)"""
     perspective = request.GET.get('perspective','document')
     if context is None: context = {}
-    if 'configuration' in request.session:
-        configuration = request.session['configuration']
-    elif configuration is None:
-        return fatalerror(request, "No configuration specified")
+    if configuration is None:
+        if 'configuration' in request.session:
+            configuration = request.session['configuration']
+        else:
+            return fatalerror(request, "No configuration specified")
     if configuration not in settings.CONFIGURATIONS:
         return fatalerror(request, "Specified configuration does not exist")
     flatargs = {
         'setdefinitions': True,
-        'declarations': True,
+        'declarations': True, #implies provenance as well
         'metadata': True,
         'toc': True,
         'slices': request.GET.get('slices',settings.CONFIGURATIONS[configuration].get('slices','p:25,s:100')), #overriden either by configuration or by user
@@ -197,6 +207,9 @@ def query_helper(request,namespace, docid, configuration=None):
 
         if query != "GET" and query[:4] != "CQL " and query[:4] != "META":
             #parse query on this end to catch syntax errors prior to sending, should be fast enough anyway
+            #first resolve variables to dummies (real ones will be handled server-side) as it won't be valid FQL otherwise
+            query = query.replace("$FOLIADOCSERVE_PROCESSOR", "PROCESSOR name \"foliadocserve\"")
+            query = query.replace("$FLAT_PROCESSOR", "PROCESSOR name \"FLAT\" version \"" + VERSION + "\" host \"" + request.get_host() + "\" src \"" + request.build_absolute_uri("/") + "\"") #also another instance in comm.py
             try:
                 query = fql.Query(query)
             except fql.SyntaxError as e:
@@ -205,8 +218,9 @@ def query_helper(request,namespace, docid, configuration=None):
         else:
             needwritepermission = False
 
-    if needwritepermission and configuration != "pub" and not flat.users.models.haswritepermission(request.user.username, namespace, request):
-        return HttpResponseForbidden("Permission denied, no write access")
+    if namespace != "pub":
+        if needwritepermission and not flat.users.models.haswritepermission(request.user.username, namespace, request):
+            return HttpResponseForbidden("Permission denied, no write access")
 
     query = "\n".join(data['queries']) #throw all queries on a big pile to transmit
     try:
@@ -244,47 +258,51 @@ def login(request):
         password = request.POST['password']
         request.session['configuration'] = request.POST['configuration']
         user = django.contrib.auth.authenticate(username=username, password=password)
+        base_prefix = settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""
         if user is not None:
             if user.is_active:
                 django.contrib.auth.login(request, user)
                 # Redirect to a success page.
                 if 'next' in request.POST:
-                    return redirect("/" + request.POST['next'])
+                    return redirect(base_prefix + "/" + request.POST['next'])
                 elif 'next' in request.GET:
-                    return redirect("/" + request.GET['next'])
+                    return redirect(base_prefix + "/" + request.GET['next'])
                 else:
-                    return redirect("/")
+                    return redirect(base_prefix + "/")
             else:
                 # Return a 'disabled account' error message
-                return render(request, 'login.html', {'error': "This account is disabled","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS , 'version': settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION} )
+                return render(request, 'login.html', {'error': "This account is disabled","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS , 'version': settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "" } )
         else:
             # Return an 'invalid login' error message.
-            return render(request, 'login.html', {'error': "Invalid username or password","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, 'version': settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION} )
+            return render(request, 'login.html', {'error': "Invalid username or password","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, 'version': settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "" } )
     else:
-        return render(request, 'login.html',{"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, "version": settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION})
+        return render(request, 'login.html',{"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, "version": settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "" })
 
 
 def logout(request):
     if 'configuration' in request.session:
         del request.session['configuration']
     django.contrib.auth.logout(request)
-    return redirect("/login")
+    base_prefix = settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""
+    return redirect(base_prefix + "/login")
 
 
 def register(request):
     if hasattr(settings, 'ALLOWREGISTRATION') and not settings.ALLOWREGISTRATION:
         return HttpResponseForbidden("Registration disabled")
 
+    base_prefix = settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""
     if request.method == 'POST':
         form = django.contrib.auth.forms.UserCreationForm(request.POST)
         if form.is_valid():
             new_user = form.save()
-            return HttpResponseRedirect("/login/")
+            return HttpResponseRedirect(base_prefix +"/login/")
     else:
         form = django.contrib.auth.forms.UserCreationForm()
     return render(request, "register.html", {
         'form': form,
         'version': settings.VERSION,
+        'base_prefix':  base_prefix
     })
 
 def fatalerror(request, e,code=404):
@@ -292,7 +310,7 @@ def fatalerror(request, e,code=404):
     if isinstance(e, Exception):
         response = render(request,'base.html', docserveerror(e))
     else:
-        response = render(request,'base.html', {'fatalerror': str(e)})
+        response = render(request,'base.html', {'fatalerror': str(e),'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""})
     response.status_code = code
     return response
 
@@ -375,11 +393,11 @@ def index(request, namespace=""):
     else:
         parentdir = ""
 
-    return render(request, 'index.html', {'namespace': namespace,'parentdir': parentdir, 'dirs': dirs, 'recursivedirs': recursivedirs, 'subdirs': subdirs, 'docs': docs, 'defaultmode': settings.DEFAULTMODE,'loggedin': request.user.is_authenticated(), 'isadmin': request.user.is_staff, 'username': request.user.username, 'configuration': settings.CONFIGURATIONS[request.session['configuration']], 'converters': get_converters(request), 'inputformatchangefunction': inputformatchangefunction(request), 'allowcopy': request.user.has_perm('auth.allowcopy'), 'allowdelete': request.user.has_perm('auth.allowdelete'),'version': settings.VERSION})
+    return render(request, 'index.html', {'namespace': namespace,'parentdir': parentdir, 'dirs': dirs, 'recursivedirs': recursivedirs, 'subdirs': subdirs, 'docs': docs, 'defaultmode': settings.DEFAULTMODE,'loggedin': request.user.is_authenticated if isinstance(request.user.is_authenticated, bool) else request.user.is_authenticated(), 'isadmin': request.user.is_staff, 'username': request.user.username, 'configuration': settings.CONFIGURATIONS[request.session['configuration']], 'converters': get_converters(request), 'inputformatchangefunction': inputformatchangefunction(request), 'allowcopy': request.user.has_perm('auth.allowcopy'), 'allowdelete': request.user.has_perm('auth.allowdelete'),'version': settings.VERSION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""})
 
 def pub(request):
     if hasattr(settings,'ALLOWPUBLICUPLOAD') and settings.ALLOWPUBLICUPLOAD:
-        return render(request, 'pub.html', {'defaultmode': settings.DEFAULTMODE,'loggedin': request.user.is_authenticated(), 'isadmin': request.user.is_staff, 'username': request.user.username,"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, 'version': settings.VERSION})
+        return render(request, 'pub.html', {'defaultmode': settings.DEFAULTMODE,'loggedin': request.user.is_authenticated if isinstance(request.user.is_authenticated, bool) else request.user.is_authenticated(), 'isadmin': request.user.is_staff, 'username': request.user.username,"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, 'version': settings.VERSION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""})
     else:
         return fatalerror(request, "Public anonymous write permission denied",403)
 
@@ -435,12 +453,13 @@ def filemanagement(request):
                 except Exception as e:
                     return fatalerror(request,e)
 
+            base_prefix = settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""
             if targetnamespace:
-                return HttpResponseRedirect("/index/" + targetnamespace )
+                return HttpResponseRedirect(base_prefix + "/index/" + targetnamespace )
             elif namespace:
-                return HttpResponseRedirect("/index/" + namespace )
+                return HttpResponseRedirect(base_prefix + "/index/" + namespace )
             else:
-                return HttpResponseRedirect("/")
+                return HttpResponseRedirect(base_prefix + "/")
 
         else:
             return fatalerror(request, "No mode specified",403)
@@ -518,10 +537,11 @@ def upload_helper(request, namespace, configuration=None, mode=None):
     else:
         docid = response['docid']
         logger.info("Succesfully uploaded " + docid + "(namespace=" + namespace+")")
+        base_prefix = settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""
         if namespace == "pub":
-            return HttpResponseRedirect("/" + mode + "/pub/" + configuration + "/" + docid  )
+            return HttpResponseRedirect(base_prefix + "/" + mode + "/pub/" + configuration + "/" + docid  )
         else:
-            return HttpResponseRedirect("/" + mode + "/" + namespace + "/" + docid  )
+            return HttpResponseRedirect(base_prefix + "/" + mode + "/" + namespace + "/" + docid  )
 
 @login_required
 def upload(request):
@@ -554,8 +574,14 @@ def pub_upload(request):
     else:
         return fatalerror(request, "Method denied",403)
 
+@csrf_exempt
+def config(request):
+    return HttpResponse(json.dumps({ "configurations": settings.CONFIGURATIONS, "defaultconfiguration": settings.DEFAULTCONFIGURATION, "defaultmode": settings.DEFAULTMODE, "allowpublicupload": settings.ALLOWPUBLICUPLOAD, "allowregistration": settings.ALLOWREGISTRATION } ), content_type="application/json")
+
+
 @login_required
 def addnamespace(request):
+    base_prefix = settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""
     if request.method == 'POST':
         namespace = request.POST['namespace'].replace('/','').replace('..','.').replace(' ','').replace('&','')
         newdirectory = request.POST['newdirectory'].replace('/','').replace('..','.').replace(' ','').replace('&','')
@@ -567,9 +593,9 @@ def addnamespace(request):
             if 'error' in response and response['error']:
                 return fatalerror(request, response['error'],403)
             elif namespace:
-                return HttpResponseRedirect("/index/" + namespace + '/' + newdirectory  )
+                return HttpResponseRedirect(base_prefix + "/index/" + namespace + '/' + newdirectory  )
             else:
-                return HttpResponseRedirect("/index/" + newdirectory  )
+                return HttpResponseRedirect(base_prefix + "/index/" + newdirectory  )
         else:
             return fatalerror(request, "Permission denied",403)
     else:
