@@ -195,10 +195,10 @@ CONFIGURATIONS = {
     'editformdirect': True, #boolean
 
     #Enable editing as correction
-    'editformcorrection': True, #boolean
+    'editformcorrection': False, #boolean
 
     #Enable editing as alternative
-    'editformalternative': True, #boolean
+    'editformalternative': False, #boolean
 
     #Enable editing as new, this allows for adding multiple or overlapping annotations of the same type
     'editformnew': True, #boolean
@@ -213,6 +213,9 @@ CONFIGURATIONS = {
     #Allow confidence values to be set/edited?
     'allowconfidence': True,
 
+    #Allow editing the structure element (i.e. its class)
+    'alloweditstructure': True,
+
     # FoLiA set to use for corrections
     #'initialcorrectionset': 'http://raw.github.com/proycon/folia/master/setdefinitions/spellingcorrection.foliaset.xml',
 
@@ -242,7 +245,34 @@ CONFIGURATIONS = {
     #Dictionary of metadata keys to lists of possible values, constrains the values in the metadata editor rather than offering a free-fill field. Example:
     #'metadataconstraints': {'language': ['fr','en','es'], 'status':['completed','inprogress']},
 
-    #'searches': [{'query': 'SELECT entity WHERE annotatortype = "manual" FOR w RETURN target', 'label': "Highlight manually annotated entities", 'changeperspective': false}]
+    #'searches': [{'query': 'SELECT entity WHERE annotatortype = "manual" FOR w RETURN target', 'label': "Highlight manually annotated entities", 'changeperspective': false}],
+
+    #Slices are  strongly tied to perspectives and determines how big of a slice to show per page for each
+    #perspective. Setting this (and choosing the desired perspective) enables pagination through documents. The value is a
+    #comma-delimited string of ``tag:number`` pairs, for instance: ``p:25,s:100`` to set a page size of 25 paragraphs in
+    #the paragraph perspective, and 100 sentences in the sentence perspective. Note that if you make the size of a page too
+    #large, you will be confronted with the error: *"Loading aborted: there was too much data to display at once"*.
+
+    #slices: 'p:25,s:100',
+
+    'converters': [
+        { 'id': 'conllu2folia',
+          'module': 'foliatools.conllu2folia',
+          'function': 'flat_convert',
+          'name': "CONLL-U",
+          'parameter_help': 'Metadata. Set <em>"direction": "rtl"</em> for right-to left languages (JSON syntax without the envelopping curly braces)', #human readable help for parameters
+          'parameter_default': '', #default parameter, JSON syntax without the envelopping {}
+          'inputextensions': ['conllu','conll'],
+        },
+        { 'id': 'rst2folia',
+          'module': 'foliatools.rst2folia',
+          'function': 'flat_convert',
+          'name': "ReStructuredText",
+          'parameter_help': '', #human readable help for parameters
+          'parameter_default': '', #default parameter, JSON syntax without the envelopping {}
+          'inputextensions': ['rst'],
+        },
+    ]
 },
 }
 
@@ -316,12 +346,22 @@ MEDIA_URL = 'http://flat.science.ru.nl/usermedia/' #not used currently by FLAT
 # Example: "/var/www/example.com/static/"
 STATIC_ROOT = BASE_DIR + '/flat/static/'
 
+
+#If you don't run at the document root of your webserver/virtual host, set BASE_PREFIX to your URL prefix (no trailing slash), e.g BASE_PREFIX = "/flat"
+#leave empty in all other scenarios
+BASE_PREFIX = ""
+if BASE_PREFIX: FORCE_SCRIPT_NAME = BASE_PREFIX
+
+
 # URL prefix for static files.
 # Example: "http://example.com/static/", "http://static.example.com/"
-STATIC_URL = '/static/'
+STATIC_URL = BASE_PREFIX + '/static/'
 
 STYLE_ROOT = BASE_DIR + '/flat/style/'
-STYLE_URL = '/style/'
+STYLE_URL = BASE_PREFIX + '/style/'
+
+SCRIPT_ROOT = BASE_DIR + '/flat/script/'
+SCRIPT_URL = BASE_PREFIX + '/script/'
 
 # Additional locations of static files
 STATICFILES_DIRS = (
@@ -329,6 +369,7 @@ STATICFILES_DIRS = (
     # Always use forward slashes, even on Windows.
     # Don't forget to use absolute paths, not relative paths.
     BASE_DIR + '/flat/style/',
+    BASE_DIR + '/flat/script/',
 )
 
 
@@ -340,7 +381,7 @@ STATICFILES_FINDERS = (
 #    'django.contrib.staticfiles.finders.DefaultStorageFinder',
 )
 
-LOGIN_URL = "/login/" #don't change this
+LOGIN_URL = BASE_PREFIX + "/login/" #don't change this
 
 
 
@@ -352,15 +393,26 @@ TEMPLATE_LOADERS = (
 #     'django.template.loaders.eggs.Loader',
 )
 
-MIDDLEWARE_CLASSES = (
-    'django.middleware.common.CommonMiddleware',
-    'django.contrib.sessions.middleware.SessionMiddleware',
-    'django.middleware.csrf.CsrfViewMiddleware',
-    'django.contrib.auth.middleware.AuthenticationMiddleware',
-    'django.contrib.messages.middleware.MessageMiddleware',
-    # Uncomment the next line for simple clickjacking protection:
-    # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
-)
+if DJANGOVERSION[0] > 1 or DJANGOVERSION[1] == 10:
+    MIDDLEWARE = (
+        'django.middleware.common.CommonMiddleware',
+        'django.contrib.sessions.middleware.SessionMiddleware',
+        'django.middleware.csrf.CsrfViewMiddleware',
+        'django.contrib.auth.middleware.AuthenticationMiddleware',
+        'django.contrib.messages.middleware.MessageMiddleware',
+        # Uncomment the next line for simple clickjacking protection:
+        # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
+    )
+else:
+    MIDDLEWARE_CLASSES = (
+        'django.middleware.common.CommonMiddleware',
+        'django.contrib.sessions.middleware.SessionMiddleware',
+        'django.middleware.csrf.CsrfViewMiddleware',
+        'django.contrib.auth.middleware.AuthenticationMiddleware',
+        'django.contrib.messages.middleware.MessageMiddleware',
+        # Uncomment the next line for simple clickjacking protection:
+        # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
+    )
 
 ROOT_URLCONF = 'flat.urls'
 
